/**
 * Le formateur qui écrit les résultats dans le format de
 * <strong>checkstyle</strong>.
 */
export const Formatter: {
    new (level: number, writer: WritableStream, options: {
        indent?: number | undefined;
    }): {
        /**
         * Le niveau de sévérité minimum des notifications affichées.
         *
         * @type {number}
         */
        "__#1@#level": number;
        /**
         * Le flux où écrire les résultats.
         *
         * @type {WritableStream}
         */
        "__#1@#writer": WritableStream;
        /**
         * La taille des indentations (en espace) ou <code>-1</code> pour ne pas
         * mettre de retour à la ligne.
         *
         * @param {number}
         */
        "__#1@#indent": number;
        /**
         * Affiche les éventuelles notifications d'un fichier.
         *
         * @param {string}      file    Le fichier analysé.
         * @param {?(Notice[])} notices La liste des notifications ou
         *                              <code>null</code>.
         */
        notify(file: string, notices: (Notice[]) | null): void;
        /**
         * Finalise l'affichage.
         *
         * @returns {Promise<void>} La promesse indiquant que tous les textes sont
         *                          écrits.
         */
        finalize(): Promise<void>;
    };
};
export type WritableStream = NodeJS.WritableStream;
export type Notice = import("../../types").Notice;
