/**
 * @module
 */
/**
 * @typedef {NodeJS.WritableStream} WritableStream
 * @typedef {import("../../types").Notice} Notice
 */
/**
 * Le formateur qui écrit les résultats brut (au format JSON).
 */
export const Formatter: {
    new (level: number, writer: WritableStream, options: {
        indent?: number | undefined;
    }): {
        /**
         * Le niveau de sévérité minimum des notifications affichées.
         *
         * @type {number}
         */
        "__#4@#level": number;
        /**
         * Le flux où écrire les résultats.
         *
         * @type {WritableStream}
         */
        "__#4@#writer": WritableStream;
        /**
         * La taille des indentations (en espace).
         *
         * @type {number}
         */
        "__#4@#indent": number;
        /**
         * Les notifications (regroupées par fichiers) ayant une sévérité supérieure
         * au niveau minimum.
         *
         * @type {Object<string, ?(Notice[])>}
         */
        "__#4@#results": {
            [x: string]: (Notice[]) | null;
        };
        /**
         * Insère les notifications dans un objet JSON.
         *
         * @param {string}      file    Le fichier analysé.
         * @param {?(Notice[])} notices La liste des notifications ou
         *                              <code>null</code>.
         */
        notify(file: string, notices: (Notice[]) | null): void;
        /**
         * Affiche les résultats.
         *
         * @returns {Promise<void>} La promesse indiquant que tous les textes sont
         *                          écrits.
         */
        finalize(): Promise<void>;
    };
};
export type WritableStream = NodeJS.WritableStream;
export type Notice = import("../../types").Notice;
