declare namespace _default {
    export { test };
    export { walk };
}
export default _default;
/**
 * Vérifie si un fichier respecte un des patrons.
 *
 * @param {string}   file      L'adresse du fichier qui sera vérifié.
 * @param {string[]} patterns  La liste des patrons.
 * @param {string}   root      L'adresse du répertoire où se trouve le dossier
 *                             <code>.metalint/</code>.
 * @param {boolean}  directory La marque indiquant si le fichier est un
 *                             répertoire.
 * @returns {boolean} <code>true</code> si le fichier respectent au moins un
 *                    patron ; sinon <code>false</code>.
 */
declare function test(file: string, patterns: string[], root: string, directory: boolean): boolean;
/**
 * Récupère toute l'arborescence des fichiers respectant un des patrons.
 *
 * @param {string[]}          bases    La liste des fichiers / répertoires
 *                                     servant de racine pour l'arborescence.
 * @param {(string[]|string)} patterns La liste des patrons.
 * @param {string}            root     L'adresse du répertoire où se trouve le
 *                                     dossier <code>.metalint/</code>.
 * @returns {Promise<string[]>} Une promesse contenant la liste des fichiers
 *                              respectant un des patrons.
 */
declare function walk(bases: string[], patterns: (string[] | string), root: string): Promise<string[]>;
